==> org.eclipse.sphinx.emf.search.ui.source_0.9.2.201601200932.jar: org/eclipse/sphinx/emf/search/ui/services/BasicModelSearchService.java <==
package org.eclipse.sphinx.emf.search.ui.services;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import org.eclipse.emf.common.util.TreeIterator;
import org.eclipse.emf.ecore.EAttribute;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.resource.Resource;
import org.eclipse.sphinx.emf.model.IModelDescriptor;
import org.eclipse.sphinx.emf.search.ui.ModelSearchMatch;
import org.eclipse.sphinx.emf.search.ui.QuerySpecification;
import org.eclipse.sphinx.emf.ui.util.RetrieveNameAttributeHelper;

public class BasicModelSearchService implements IModelSearchService {

	private RetrieveNameAttributeHelper helper = new RetrieveNameAttributeHelper();

	@Override
	public List<ModelSearchMatch> getMatches(IModelDescriptor modelDescriptor, QuerySpecification spec) {
		return getMatches(modelDescriptor.getLoadedResources(true), spec);
	}

	@Override
	public List<ModelSearchMatch> getMatches(Collection<Resource> resources, QuerySpecification spec) {
		List<ModelSearchMatch> result = new ArrayList<ModelSearchMatch>();
		for (Resource resource : resources) {
			TreeIterator<EObject> allContents = resource.getAllContents();
			while (allContents.hasNext()) {
				EObject eObject = allContents.next();
				EAttribute nameAttribute = helper.getNameAttribute(eObject);
				if (nameAttribute != null) {
					Object name = eObject.eGet(nameAttribute);
					if (name != null) {
						// TODO Add support for *, ?, \*, \?, \\
						if (spec.isCaseSensitive()) {
							if (name.toString().equals(spec.getPattern())) {
								result.add(createModelSearchMatch(eObject));
							}
						} else if (name.toString().equalsIgnoreCase(spec.getPattern())) {
							result.add(createModelSearchMatch(eObject));
						}
					}
				}
			}
		}
		return result;
	}

	private ModelSearchMatch createModelSearchMatch(EObject eObject) {
		ModelSearchMatch match = new ModelSearchMatch(eObject);
		return match;
	}
}

==> org.eclipse.sphinx.emf.search.ui.source_0.11.0.201706140911.jar: org/eclipse/sphinx/emf/search/ui/services/BasicModelSearchService.java <==
/**
 * <copyright>
 *
 * Copyright (c) 2015-2017 itemis and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     itemis - Initial API and implementation
 *     itemis - [501899] Use base index instead of IncQuery patterns
 *
 * </copyright>
 */
package org.eclipse.sphinx.emf.search.ui.services;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import org.eclipse.emf.common.util.TreeIterator;
import org.eclipse.emf.ecore.EAttribute;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.resource.Resource;
import org.eclipse.sphinx.emf.metamodel.IMetaModelDescriptor;
import org.eclipse.sphinx.emf.metamodel.services.AbstractMetaModelService;
import org.eclipse.sphinx.emf.model.IModelDescriptor;
import org.eclipse.sphinx.emf.search.ui.ModelSearchMatch;
import org.eclipse.sphinx.emf.search.ui.QuerySpecification;
import org.eclipse.sphinx.emf.ui.util.RetrieveNameAttributeHelper;

public class BasicModelSearchService extends AbstractMetaModelService implements IModelSearchService {

	private RetrieveNameAttributeHelper helper = new RetrieveNameAttributeHelper();

	public BasicModelSearchService(Collection<IMetaModelDescriptor> mmDescriptors) {
		super(mmDescriptors);
	}

	@Override
	public List<ModelSearchMatch> getMatches(IModelDescriptor modelDescriptor, QuerySpecification spec) {
		return getMatches(modelDescriptor.getLoadedResources(true), spec);
	}

	@Override
	public List<ModelSearchMatch> getMatches(Collection<Resource> resources, QuerySpecification spec) {
		List<ModelSearchMatch> result = new ArrayList<ModelSearchMatch>();
		for (Resource resource : resources) {
			TreeIterator<EObject> allContents = resource.getAllContents();
			while (allContents.hasNext()) {
				EObject eObject = allContents.next();
				EAttribute nameAttribute = helper.getNameAttribute(eObject);
				if (nameAttribute != null) {
					Object name = eObject.eGet(nameAttribute);
					if (name != null) {
						// TODO Add support for *, ?, \*, \?, \\
						if (spec.isCaseSensitive()) {
							if (name.toString().equals(spec.getPattern())) {
								result.add(createModelSearchMatch(eObject));
							}
						} else if (name.toString().equalsIgnoreCase(spec.getPattern())) {
							result.add(createModelSearchMatch(eObject));
						}
					}
				}
			}
		}
		return result;
	}

	private ModelSearchMatch createModelSearchMatch(EObject eObject) {
		ModelSearchMatch match = new ModelSearchMatch(eObject);
		return match;
	}
}
